@echo off
rem *****************************
rem * TELEMAC-MASCARET settings *
rem *****************************
rem Path to TELEMAC root dir
for %%a in ("%~dp0.") do set HOMETEL=%%~dpa
set HOMETEL=%HOMETEL:~0,-1%
rem Path to dependencies
set TELEMACDEPS=C:\telemac-deps
rem Path to this file
set SOURCEFILE=%~dp0%~n0%~x0
rem Configuration file
set SYSTELCFG=%HOMETEL%\configs\systel.edf.cfg
rem Name of the configuration to use
set USETELCFG=win.gnu

rem Add Python to PATH, its modules to PYTHONPATH and set it as the
rem default one to launch Python scripts from the command line
setlocal enabledelayedexpansion
set python=python-3.7.9
endlocal & (
  set "PATH=%TELEMACDEPS%\%python%;%TELEMACDEPS%\%python%\Scripts;%PATH%"
  set "PYTHONPATH=%TELEMACDEPS%\%python%\Lib\site-packages"
  reg delete HKCU\SOFTWARE\Classes\.py\OpenWithProgids /f 1>null
  reg add HKCU\SOFTWARE\Classes\.py\shell\open\command /ve /f /d "%TELEMACDEPS%\%python%\python.exe \"%%1\" %%*" 1>null
)

rem Add Mingw to PATH is it is found
call :find_mingw

rem Add TELEMAC binaries directory to PATH
set PATH=%HOMETEL%\builds\%USETELCFG%\lib;%PATH%
rem Add TELEMAC Python scripts to PATH and to Python environment
set PATH=%HOMETEL%\scripts\python3;%PATH%
set PYTHONPATH=%HOMETEL%\scripts\python3;%PYTHONPATH%
set PYTHONPATH=%HOMETEL%\builds\%USETELCFG%\wrap_api\lib;%PYTHONPATH%


rem External libraries versions
rem HDF
set HDF5HOME=%TELEMACDEPS%\hdf5-1.10.8
set PATH=%HDF5HOME%\bin;%PATH%
rem MED
set MEDHOME=%TELEMACDEPS%\med-4.1.0
set PATH=%MEDHOME%\bin;%PATH%
rem METIS
set METISHOME=%TELEMACDEPS%\metis-5.1.1
set PATH=%METISHOME%\bin;%PATH%
rem MSPMPI
set MPIHOME=%TELEMACDEPS%\msmpi-10.1.2
set PATH=%MPIHOME%\bin;%PATH%
rem LAPACK, SCALAPACK and MUMPS
set LAPACKHOME=%TELEMACDEPS%\lapack-3.10.0
set SCALAPACKHOME=%TELEMACDEPS%\scalapack-2.1.0
set MUMPSHOME=%TELEMACDEPS%\mumps-5.4.1
rem AED
set AEDHOME=%TELEMACDEPS%\libaed2-1.3.0
rem GOTM
set GOTMHOME=%TELEMACDEPS%\gotm-2019-06-14-opentelemac
set PATH=%GOTMHOME%\bin;%PATH%

exit /b 0

:find_mingw
rem Try to find Mingw in current user PATH
for /f "delims=" %%a in ('"where mingw32-make 2>nul"') do set MINGW_PATH=%%a
rem If not found, add usual Mingw location to PATH
if not defined MINGW_PATH set PATH=C:\mingw64\bin;%PATH%
for /f "delims=" %%a in ('"where mingw32-make 2>nul"') do set MINGW_PATH=%%a
if not defined MINGW_PATH (
  echo Warning: Mingw not found. Please ensure that Mingw bin folder is in your PATH or
  echo you will not be able to compile TELEMAC-MASCARET or compile user Fortran code.
)

exit /b 0